@@ -14,10 +14,10 @@ import pandas as pd
 
 
 
-from . import CIG.cig_network as cig
-from . import IT_nil.nil
-from . import IT_node.IT_node
-from . import IT.Interval_Tree
+from CIG import cig_network as cig
+from IT_nil import nil
+from IT_node import IT_node
+from IT import Interval_Tree
 
 
 
